@@ -154,7 +154,8 @@ modelsum <- function(formula,  family="gaussian", data, adjust=NULL, na.action=n
   if(!missing(data))
   {
     data <- keep.labels(data)
-    temp.call$data <- call("keep.labels", temp.call$data)
+    # instead of call("keep.labels", ...), which breaks when arsenal isn't loaded (Can't find "keep.labels")
+    temp.call$data <- as.call(list(keep.labels, temp.call$data))
   }
 
   ## if(is.null(temp.call$weights)) {
