@@ -46,29 +46,29 @@ test_that("write2.freqlist -> doc", {
 ###########################################################################################################
 #### External output
 ###########################################################################################################
-
-test_that("write2.knitr_kable -> HTML", {
-  if(require(knitr))
-  {
-    expect_write2_worked(write2html, knitr::kable(head(mockstudy)), reference = "write2.kable.html.md")
-  } else skip("library(knitr) not available.")
-})
-
-test_that("write2.xtable -> HTML", {
-  if(require(xtable))
-  {
-    expect_write2_worked(write2html, xtable::xtable(head(mockstudy), caption = "My xtable"), reference = "write2.xtable.html.md",
-                         type = "html", comment = FALSE, include.rownames = FALSE, caption.placement = 'top')
-  } else skip("library(xtable) not available.")
-})
-
-test_that("write2.character (pander) -> HTML", {
-  if(require(pander))
-  {
-    expect_write2_worked(write2html, pander::pander_return(head(mockstudy)), reference = "write2.pander.html.md")
-  } else skip("library(pander) not available.")
-})
-
+#
+# test_that("write2.knitr_kable -> HTML", {
+#   if(require(knitr))
+#   {
+#     expect_write2_worked(write2html, knitr::kable(head(mockstudy)), reference = "write2.kable.html.md")
+#   } else skip("library(knitr) not available.")
+# })
+#
+# test_that("write2.xtable -> HTML", {
+#   if(require(xtable))
+#   {
+#     expect_write2_worked(write2html, xtable::xtable(head(mockstudy), caption = "My xtable"), reference = "write2.xtable.html.md",
+#                          type = "html", comment = FALSE, include.rownames = FALSE, caption.placement = 'top')
+#   } else skip("library(xtable) not available.")
+# })
+#
+# test_that("write2.character (pander) -> HTML", {
+#   if(require(pander))
+#   {
+#     expect_write2_worked(write2html, pander::pander_return(head(mockstudy)), reference = "write2.pander.html.md")
+#   } else skip("library(pander) not available.")
+# })
+#
 ###########################################################################################################
 #### List output
 ###########################################################################################################
